lcvtoolbox.core.schemas.cvat\_typed.CvatApiShape
================================================

.. currentmodule:: lcvtoolbox.core.schemas.cvat_typed

.. autoclass:: CvatApiShape
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatApiShape.__init__
      ~CvatApiShape.clear
      ~CvatApiShape.copy
      ~CvatApiShape.fromkeys
      ~CvatApiShape.get
      ~CvatApiShape.items
      ~CvatApiShape.keys
      ~CvatApiShape.pop
      ~CvatApiShape.popitem
      ~CvatApiShape.setdefault
      ~CvatApiShape.update
      ~CvatApiShape.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatApiShape.id
      ~CvatApiShape.type
      ~CvatApiShape.occluded
      ~CvatApiShape.z_order
      ~CvatApiShape.points
      ~CvatApiShape.rotation
      ~CvatApiShape.outside
      ~CvatApiShape.attributes
      ~CvatApiShape.frame
      ~CvatApiShape.label_id
      ~CvatApiShape.source
   
   